==> ssp-center-api-0.6.12-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotSck.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class SlotSck implements Serializable {

    private static final long serialVersionUID = 7944219353292529634L;

    private Long              id;

    private Long              slotId;

    private Long              sckId;

    private String            scUrl;

    private Date              gmtCreate;

    private Date              gmtModified;

    private Integer           downloadNum;

    private String            imageText;

    private Integer           isDelete;

    private Integer           checkStatus = 0;

    private Integer           sckSource = 0;

    private Double            ctr;

    private Integer           sort;

    /** 素材文案-标题 */
    private String extTitle;
    /** 素材文案-描述 */
    private String extDesc;

    /** 素材上传时间 */
    private Date sckGmtCreate;
    /**
     * 素材曝光数
     */
    private Long exposeCount;
    /**
     * 失效素材标签，1：是，0：不是
     */
    private Integer noUse;

    @Override
    public int hashCode() {
        return super.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (obj instanceof  SlotSck) {
            SlotSck slotSck = (SlotSck) obj;
            // 需要比较的字段相等，则这两个对象相等
            if (this.sckId.equals(slotSck.getSckId())) {
                return true;
            }
        }
        return false;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getSckId() {
        return sckId;
    }

    public void setSckId(Long sckId) {
        this.sckId = sckId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getScUrl() {
        return scUrl;
    }

    public void setScUrl(String scUrl) {
        this.scUrl = scUrl;
    }

    public Integer getDownloadNum() {
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum) {
        this.downloadNum = downloadNum;
    }

    public String getImageText() {
        return imageText;
    }

    public void setImageText(String imageText) {
        this.imageText = imageText;
    }

    public Integer getIsDelete() {
        return isDelete;
    }

    public void setIsDelete(Integer isDelete) {
        this.isDelete = isDelete;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getSckSource() {
        return sckSource;
    }

    public void setSckSource(Integer sckSource) {
        this.sckSource = sckSource;
    }

    public Double getCtr() {
        return ctr;
    }

    public void setCtr(Double ctr) {
        this.ctr = ctr;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public String getExtTitle() {
        return extTitle;
    }

    public void setExtTitle(String extTitle) {
        this.extTitle = extTitle;
    }

    public String getExtDesc() {
        return extDesc;
    }

    public void setExtDesc(String extDesc) {
        this.extDesc = extDesc;
    }

    public Date getSckGmtCreate() {
        return sckGmtCreate;
    }

    public void setSckGmtCreate(Date sckGmtCreate) {
        this.sckGmtCreate = sckGmtCreate;
    }

    public Long getExposeCount() {
        return exposeCount;
    }

    public void setExposeCount(Long exposeCount) {
        this.exposeCount = exposeCount;
    }

    public Integer getNoUse() {
        return noUse;
    }

    public void setNoUse(Integer noUse) {
        this.noUse = noUse;
    }
}

==> ssp-center-api-0.7.01-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotSck.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class SlotSck implements Serializable {

    private static final long serialVersionUID = 7944219353292529634L;

    private Long              id;

    private Long              slotId;

    private Long              sckId;

    private String            scUrl;

    private Date              gmtCreate;

    private Date              gmtModified;

    private Integer           downloadNum;

    private String            imageText;

    private Integer           isDelete;

    private Integer           checkStatus = 0;

    private Integer           sckSource = 0;

    private Double            ctr;

    private Integer           sort;

    /** 素材文案-标题 */
    private String extTitle;
    /** 素材文案-描述 */
    private String extDesc;

    /** 素材上传时间 */
    private Date sckGmtCreate;
    /**
     * 素材曝光数
     */
    private Long exposeCount;
    /**
     * 失效素材标签，1：是，0：不是
     */
    private Integer noUse;

    private String strategyType;

    @Override
    public int hashCode() {
        return super.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (obj instanceof  SlotSck) {
            SlotSck slotSck = (SlotSck) obj;
            // 需要比较的字段相等，则这两个对象相等
            if (this.sckId.equals(slotSck.getSckId())) {
                return true;
            }
        }
        return false;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getSckId() {
        return sckId;
    }

    public void setSckId(Long sckId) {
        this.sckId = sckId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getScUrl() {
        return scUrl;
    }

    public void setScUrl(String scUrl) {
        this.scUrl = scUrl;
    }

    public Integer getDownloadNum() {
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum) {
        this.downloadNum = downloadNum;
    }

    public String getImageText() {
        return imageText;
    }

    public void setImageText(String imageText) {
        this.imageText = imageText;
    }

    public Integer getIsDelete() {
        return isDelete;
    }

    public void setIsDelete(Integer isDelete) {
        this.isDelete = isDelete;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getSckSource() {
        return sckSource;
    }

    public void setSckSource(Integer sckSource) {
        this.sckSource = sckSource;
    }

    public Double getCtr() {
        return ctr;
    }

    public void setCtr(Double ctr) {
        this.ctr = ctr;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public String getExtTitle() {
        return extTitle;
    }

    public void setExtTitle(String extTitle) {
        this.extTitle = extTitle;
    }

    public String getExtDesc() {
        return extDesc;
    }

    public void setExtDesc(String extDesc) {
        this.extDesc = extDesc;
    }

    public Date getSckGmtCreate() {
        return sckGmtCreate;
    }

    public void setSckGmtCreate(Date sckGmtCreate) {
        this.sckGmtCreate = sckGmtCreate;
    }

    public Long getExposeCount() {
        return exposeCount;
    }

    public void setExposeCount(Long exposeCount) {
        this.exposeCount = exposeCount;
    }

    public Integer getNoUse() {
        return noUse;
    }

    public void setNoUse(Integer noUse) {
        this.noUse = noUse;
    }

    public String getStrategyType() {
        return strategyType;
    }

    public void setStrategyType(final String strategyType) {
        this.strategyType = strategyType;
    }
}
